@@ -1,7 +1,7 @@
 
 # Imports
 import stouputils as stp
-from ..utils.io import write_to_file
+from ..utils.io import write_file
 from ..constants import VANILLA_BLOCK_FOR_ORES, VANILLA_BLOCK
 
 # Main function
@@ -12,7 +12,7 @@ def main(config: dict):
 	if any(VANILLA_BLOCK_FOR_ORES == data.get(VANILLA_BLOCK) for data in database.values()):
 
 		# Add the block to veinminer tag
-		write_to_file(f"{config['build_datapack']}/data/enchantplus/tags/block/veinminer.json", stp.super_json_dump({"values": [VANILLA_BLOCK_FOR_ORES["id"]]}))
+		write_file(f"{config['build_datapack']}/data/enchantplus/tags/block/veinminer.json", stp.super_json_dump({"values": [VANILLA_BLOCK_FOR_ORES["id"]]}))
 
 		# Final print
 		stp.debug("Special datapack compatibility done for NeoEnchant's veinminer!")
